==> thundra_ai-0.0.11.tar.gz: thundra_ai-0.0.11/README.md <==
## <p align="center">Thundra</p>
[![Label](https://img.shields.io/badge/WHATSAPP-AUTOMATION-20B2AA?style=for-the-badge&logo=whatsapp)]()
[![Label](https://img.shields.io/badge/AGENT-LANGCHAIN-20B2AA?style=for-the-badge&logo=openai)]()
[![Label](https://img.shields.io/badge/whatsmeow-wrapper-20B2AA?style=for-the-badge&logo=go)]()

[![Release](https://github.com/krypton-byte/thundra/actions/workflows/release.yml/badge.svg)](https://github.com/krypton-byte/thundra/actions/workflows/release.yml)
[![Pypi](https://img.shields.io/pypi/v/neonize.svg?logo=pypi)]()
![PyPI - Downloads](https://img.shields.io/pypi/dm/thundra?logo=pypi)

<p align="center"><img src="https://raw.githubusercontent.com/krypton-byte/thundra/master/assets/logo.jpg" width="150px"/></p>

Thundra is a framework designed to streamline the development of WhatsApp bots and automations. It provides a solid foundation and abstraction layer to simplify the process of creating and managing WhatsApp bots for various purposes.

## Features

- **Abstraction Layer**: Thundra abstracts away the complexities of interacting with the WhatsApp API, allowing developers to focus on bot logic rather than low-level implementation details.
- **Ease of Use**: Thundra is designed to be beginner-friendly, with clear documentation and intuitive APIs.
- **Modular Architecture**: The framework follows a modular architecture, making it easy to extend and customize functionality according to specific project requirements.
- **Scalability**: Thundra is built with scalability in mind, capable of handling large volumes of messages and interactions.
- **Built-in Tools**: Thundra includes built-in tools and utilities to facilitate common tasks such as message parsing, state management, and data storage.


## Getting Started

To get started with Thundra, follow these steps:

1. **Installation**: Install Thundra via pip:

    ```
    pip install thundra-ai
    ```

2. **Configuration**: Set up your WhatsApp account credentials and other configurations in the `thundra.toml` file.

3. **Create a Bot**: Write your bot logic using the Thundra framework. Here's a simple example:

    ```bash
    > thundra create
    > thundra run
    ```

4. **Deploy**: Deploy your bot to your preferred hosting environment. Thundra is compatible with various deployment options, including cloud platforms and self-hosted servers.

5. **Interact**: Once deployed, your bot is ready to interact with users on WhatsApp. Start sending messages and observing bot responses.

For more detailed instructions and examples, refer to the [documentation](https://thundra.krypton-byte.me).

## Contributing

We welcome contributions from the community! If you have ideas for improvements, bug fixes, or new features, feel free to open an issue or submit a pull request on GitHub.

## License

Thundra is licensed under the Apache License. See the [LICENSE](LICENSE) file for details.

## Contact

If you have any questions, suggestions, or feedback, you can reach out to us at [krypton-byte](mailto:rosid6434@gmail.com) or join our [community Discord server]().

==> thundra_ai-0.1.3.tar.gz: thundra_ai-0.1.3/README.md <==
## <p align="center">Thundra</p>
[![Label](https://img.shields.io/badge/WHATSAPP-AUTOMATION-20B2AA?style=for-the-badge&logo=whatsapp)]()
[![Label](https://img.shields.io/badge/AGENT-LANGCHAIN-20B2AA?style=for-the-badge&logo=openai)]()
[![Label](https://img.shields.io/badge/whatsmeow-wrapper-20B2AA?style=for-the-badge&logo=go)]()

[![Release](https://github.com/krypton-byte/thundra/actions/workflows/release.yml/badge.svg)](https://github.com/krypton-byte/thundra/actions/workflows/release.yml)
[![Pypi](https://img.shields.io/pypi/v/thundra-ai.svg?logo=pypi)]()
![PyPI - Downloads](https://img.shields.io/pypi/dm/thundra-ai?logo=pypi)

<p align="center"><img src="https://raw.githubusercontent.com/krypton-byte/thundra/master/assets/logo.jpg" width="150px"/></p>

Thundra is a framework designed to streamline the development of WhatsApp bots and automations. It provides a solid foundation and abstraction layer to simplify the process of creating and managing WhatsApp bots for various purposes.

## Features

- **Abstraction Layer**: Thundra abstracts away the complexities of interacting with the WhatsApp API, allowing developers to focus on bot logic rather than low-level implementation details.
- **Ease of Use**: Thundra is designed to be beginner-friendly, with clear documentation and intuitive APIs.
- **Modular Architecture**: The framework follows a modular architecture, making it easy to extend and customize functionality according to specific project requirements.
- **Scalability**: Thundra is built with scalability in mind, capable of handling large volumes of messages and interactions.
- **Built-in Tools**: Thundra includes built-in tools and utilities to facilitate common tasks such as message parsing, state management, and data storage.


## Getting Started

To get started with Thundra, follow these steps:

1. **Installation**: Install Thundra via pip:

    ```
    pip install thundra-ai
    ```

2. **Configuration**: Set up your WhatsApp account credentials and other configurations in the `thundra.toml` file.

3. **Create a Bot**: Write your bot logic using the Thundra framework. Here's a simple example:

    ```bash
    > thundra create
    > thundra run
    ```

4. **Deploy**: Deploy your bot to your preferred hosting environment. Thundra is compatible with various deployment options, including cloud platforms and self-hosted servers.

5. **Interact**: Once deployed, your bot is ready to interact with users on WhatsApp. Start sending messages and observing bot responses.

For more detailed instructions and examples, refer to the [documentation](https://thundra.krypton-byte.me).

## Contributing

We welcome contributions from the community! If you have ideas for improvements, bug fixes, or new features, feel free to open an issue or submit a pull request on GitHub.

## License

Thundra is licensed under the Apache License. See the [LICENSE](LICENSE) file for details.

## Contact

If you have any questions, suggestions, or feedback, you can reach out to us at [krypton-byte](mailto:rosid6434@gmail.com) or join our [community Discord server]().
